@@ -41,47 +41,55 @@ def CCG_metrics(st1, st2, K, T, nbins=None, tbin=None):
     irange2 = np.arange(nbins-50, nbins-10)
     irange3 = np.arange(nbins+10, nbins+50)
 
-    Q00 = K[irange1].sum() / (len(irange1) * tbin * len(st1) * len(st2) /T)
-    Q1 = K[irange2].sum() / (len(irange2) * tbin * len(st1) * len(st2) /T)
-    Q2 = K[irange3].sum() / (len(irange3) * tbin * len(st1) * len(st2) /T)
-    Q01 = np.maximum(Q1, Q2)
+    R00 = K[irange1].sum() / (len(irange1) * tbin * len(st1) * len(st2) /T)
+    R1 = K[irange2].sum() / (len(irange2) * tbin * len(st1) * len(st2) /T)
+    R2 = K[irange3].sum() / (len(irange3) * tbin * len(st1) * len(st2) /T)
+    R01 = np.maximum(R1, R2)
 
-    R00 = np.maximum(K[irange2].mean(), K[irange3].mean())
-    R00 = np.maximum(R00, K[irange1].mean())
+    Q00 = np.maximum(K[irange2].mean(), K[irange3].mean())
+    Q00 = np.maximum(Q00, K[irange1].mean())
 
     a = K[nbins]
     K[nbins] = 0
 
-    Qi = np.zeros(10,)
     Ri = np.zeros(10,)
+    Qi = np.zeros(10,)
     for i in range(1,11):
         irange = np.arange(nbins-i, nbins+i+1)
-        Qi0 = K[irange].sum() / (2*i*tbin*len(st1)*len(st2)/T)
-        Qi[i-1] = Qi0
+        Ri0 = K[irange].sum() / (2*i*tbin*len(st1)*len(st2)/T)
+        Ri[i-1] = Ri0
 
         n = K[irange].sum()/2
-        lam = R00 * i
+        lam = Q00 * i
 
         p = 1/2 * (1 + math.erf((n-lam)/(1e-10 + 2*lam)**.5))
 
-        Ri[i-1] = p
+        Qi[i-1] = p
 
     K[nbins] = a
-    Q12 = np.min(Qi) / (1e-10 + np.maximum(Q00, Q01))
-    R12 = np.min(Ri)
+
+    # NOTE: The variable names R12 and Q12 are reversed here compared to past
+    #       versions of Kilosort, but the code remains unchanged. This change
+    #       was made to be consistent with the methods in the Kilosort4 paper.
+    R12 = np.min(Ri) / (1e-10 + np.maximum(R00, R01))
+    Q12 = np.min(Qi)
 
     #print('%4.2f, %4.2f, %4.2f'%(R00, Q12, R12))
-    return Q12, R12, R00
+    return R12, Q12, Q00
 
 def check_CCG(st1, st2=None, nbins = 500, tbin  = 1/1000, acg_threshold=0.2,
               ccg_threshold=0.25):
+    # NOTE: The default `acg_threshold=0.2` is different from the value of 0.1
+    #       used for the Kilosort4 paper. We felt this better reflects common
+    #       practice for determining 'good' units, but you can set
+    #       `acg_threshold=0.1` in your run settings for stricter criteria.
     if st2 is None:
         st2 = st1.copy()
     K , T= compute_CCG(st1, st2, nbins = nbins, tbin = tbin)
-    Q12, R12, R00 = CCG_metrics(st1, st2, K, T,  nbins = nbins, tbin = tbin)
-    is_refractory    = Q12<acg_threshold  and (R12<.2)#  or R00<.25)
-    cross_refractory = Q12<ccg_threshold and (R12<.05)# or R00<.25)
-    return is_refractory, cross_refractory, Q12
+    R12, Q12, Q00 = CCG_metrics(st1, st2, K, T,  nbins = nbins, tbin = tbin)
+    is_refractory    = R12<acg_threshold  and (Q12<.2)#  or Q00<.25)
+    cross_refractory = R12<ccg_threshold and (Q12<.05)# or Q00<.25)
+    return is_refractory, cross_refractory, R12
 
 def similarity(Wall, W, nt=61):
     WtW = conv1d(W.reshape(-1, 1,nt), W.reshape(-1, 1 ,nt), padding = nt) 
@@ -99,15 +107,15 @@ def refract(iclust2, st0, acg_threshold=0.2, ccg_threshold=0.25):
 
     is_refractory    = np.zeros(Nfilt, )
     cross_refractory = np.zeros(Nfilt, )
-    Q12 = np.zeros(Nfilt, )
+    R12 = np.zeros(Nfilt, )
 
     for kk in range(Nfilt):    
         ix = iclust2==kk
         st1 = st0[ix]
 
         if (len(st1) > 10) and ((st1.max() - st1.min()) != 0):
-            is_refractory[kk], cross_refractory[kk], Q12[kk] = check_CCG(
+            is_refractory[kk], cross_refractory[kk], R12[kk] = check_CCG(
                 st1, acg_threshold=acg_threshold, ccg_threshold=ccg_threshold
                 )
 
-    return is_refractory, Q12
\ No newline at end of file
+    return is_refractory, R12
\ No newline at end of file
